from pyramid_scss.tests import PyramidScssTestCase, DummyRequest
import pyramid_scss.controller as controller

class ControllerTestCase(PyramidScssTestCase):
    def test_get_scss(self):
        request = DummyRequest(self.config.registry)
        request.matchdict.update({
            'css_path': 'test'
        })

        scss = controller.get_scss(None, request)
        assert self.fixtures.get('test.scss') == controller.get_scss(None, request)



import string
import random

from pyramid_scss.tests import PyramidScssTestCase, DummyRequest
import pyramid_scss.controller as controller

class CacheTestCase(PyramidScssTestCase):
    @staticmethod
    def generate_id(count):
        return ''.join(random.choice(string.ascii_uppercase + string.lowercase + string.digits) for i in range(count))

    def test_cache(self):
        self.renderer.options.update({
            'cache': True
        })

        request = DummyRequest(self.config.registry)
        request.matchdict.update({
            'css_path': 'test'
        })

        response = self.renderer(self.fixtures.get('test.scss'), {'request': request})

        random_id = CacheTestCase.generate_id(8)
        modified = self.fixtures.get('test.scss') + '\n#{id} {{color: black}}'.format(id=random_id)
        new_response = self.renderer(modified, {'request': request})

        assert response == new_response
        assert random_id not in new_response

    def test_nocache(self):
        self.renderer.options.update({
            'cache': False
        })

        request = DummyRequest(self.config.registry)
        request.matchdict.update({
            'css_path': 'test'
        })

        response = self.renderer(self.fixtures.get('test.scss'), {'request': request})

        random_id = CacheTestCase.generate_id(8)
        modified = self.fixtures.get('test.scss') + '\n#{id} {{color: black}}'.format(id=random_id)
        new_response = self.renderer(modified, {'request': request})

        assert response != new_response
        assert random_id in new_response



from pyramid_scss.tests import PyramidScssTestCase, DummyRequest
import pyramid_scss.controller as controller

class RendererTestCase(PyramidScssTestCase):
    def test_nocompress(self):
        self.renderer.options.update({
            'compress': False
        })

        request = DummyRequest(self.config.registry)
        request.matchdict.update({
            'css_path': 'test'
        })

        rendered = self.renderer(self.fixtures.get('test.scss'), {'request': request})
        assert rendered == self.fixtures.get('test_nocompress.css')

    def test_compress(self):
        self.renderer.options.update({
            'compress': True
        })

        request = DummyRequest(self.config.registry)
        request.matchdict.update({
            'css_path': 'test'
        })

        rendered = self.renderer(self.fixtures.get('test.scss'), {'request': request})
        assert rendered == self.fixtures.get('test_compress.css')

    def test_import(self):
        request = DummyRequest(self.config.registry)
        request.matchdict.update({
            'css_path': 'import'
        })

        rendered = self.renderer(self.fixtures.get('import.scss'), {'request': request})
        assert '#imported_resource' in rendered

    def test_spritemap(self):
        self.renderer.options.update({
            'compress': True
        })

        request = DummyRequest(self.config.registry)
        request.matchdict.update({
            'css_path': 'test_spritemap'
        })

        rendered = self.renderer(self.fixtures.get('test_spritemap.scss'), {'request': request})
        assert '.arrow_left{width:16px;height:16px;background-position:0 0}' in rendered
        assert '.arrow_right{width:16px;height:16px;background-position:0 -16px}' in rendered



import os
import csv
from collections import namedtuple

from unittest import TestCase
from pyramid import testing
from pyramid.asset import abspath_from_asset_spec
from pyramid.renderers import get_renderer

import pyramid_scss

class PyramidScssTestCase(TestCase):
    scss_settings = {
        'scss.asset_path': """
            pyramid_scss.tests:fixtures
            pyramid_scss.tests:fixtures/resources
        """,
        'scss.static_path': 'pyramid_scss.tests:fixtures/static',
        'scss.static_url_root': '/static/',
        'scss.output_path': 'pyramid_scss.tests:fixtures/compiled',
        'scss.output_url_root': '/compiled/',
        'scss.cache': True,
    }

    def setUp(self):
        self.config = testing.setUp(settings=self.scss_settings)
        pyramid_scss.includeme(self.config)
        self.renderer = get_renderer('scss')

        self._load_fixtures()

    def _load_fixtures(self):
        self.fixtures = {}
        fixture_path = abspath_from_asset_spec('pyramid_scss.tests:fixtures')
        for path, dirs, files in os.walk(fixture_path):
            for name in files:
                with open(os.path.join(path, name)) as f:
                    self.fixtures.setdefault(name, f.read())


class DummyRequest(object):
    def __init__(self, registry):
        self.registry = registry
        self.matchdict = {}
        self.response = namedtuple('Response', ['content_type'])
